==> leechcraft-0.3.65.tar.bz2: leechcraft-0.3.65/src/plugins/poshuku/plugins/fua/leechcraft_poshuku_fua_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>Changer</name>
    <message>
        <location filename="changer.ui" line="14"/>
        <source>Fake user agent</source>
        <translation>Поддельный user-agent</translation>
    </message>
    <message>
        <location filename="changer.ui" line="25"/>
        <source>Domain:</source>
        <translation>Домен:</translation>
    </message>
    <message>
        <location filename="changer.ui" line="35"/>
        <source>Agent:</source>
        <translation>Агент:</translation>
    </message>
    <message>
        <location filename="changer.ui" line="45"/>
        <source>ID string:</source>
        <translation>Строка:</translation>
    </message>
    <message>
        <location filename="changer.ui" line="57"/>
        <source>%Platform% and %Subplatform% are expanded to the windowing system and the operation system.
%Security% is expanded to U if SSL is enabled, otherwise N.
%Locale% is replaced with current locale name.
%WebKitVersion% is expanded to WebKit version.
%AppVersion% is expanded to the application&apos;s version.</source>
        <translation>%Platform% и %Subplatform% заменяются оконной подсистемой и операционной системой.
%Security% заменяется на U, если SSL включен, в противном случае на N.
%Locale% заменяется именем текущей локали.
%WebKitVersion% заменяется версией движка WebKit.
%AppVersion% заменяется версией приложения.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Poshuku::Plugins::Fua::FUA</name>
    <message>
        <location filename="fua.cpp" line="60"/>
        <source>Domain</source>
        <translation>Домен</translation>
    </message>
    <message>
        <location filename="fua.cpp" line="61"/>
        <source>Agent</source>
        <translation>Агент</translation>
    </message>
    <message>
        <location filename="fua.cpp" line="62"/>
        <source>Identification string</source>
        <translation>Строка идентификации</translation>
    </message>
    <message>
        <location filename="fua.cpp" line="97"/>
        <source>Allows to set fake user agents for different sites.</source>
        <translation>Позволяет устанавливать поддельные user-agent для различных сайтов.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="settings.ui" line="14"/>
        <source>Form</source>
        <translation>Ыа</translation>
    </message>
    <message>
        <location filename="settings.ui" line="27"/>
        <source>Add...</source>
        <translation>Добавить...</translation>
    </message>
    <message>
        <location filename="settings.ui" line="34"/>
        <source>Modify...</source>
        <translation>Изменить...</translation>
    </message>
    <message>
        <location filename="settings.ui" line="41"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="settings.ui" line="65"/>
        <source>Changes would be applied immediately</source>
        <translation>Изменения будут применены сразу</translation>
    </message>
</context>
</TS>

==> leechcraft-0.3.80_rc20101109.tar.bz2: leechcraft-0.3.75_rc20101109/src/plugins/poshuku/plugins/fua/leechcraft_poshuku_fua_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>Changer</name>
    <message>
        <location filename="changer.ui" line="14"/>
        <source>Fake user agent</source>
        <translation>Поддельный user-agent</translation>
    </message>
    <message>
        <location filename="changer.ui" line="25"/>
        <source>Domain:</source>
        <translation>Домен:</translation>
    </message>
    <message>
        <location filename="changer.ui" line="35"/>
        <source>Agent:</source>
        <translation>Агент:</translation>
    </message>
    <message>
        <location filename="changer.ui" line="45"/>
        <source>ID string:</source>
        <translation>Строка:</translation>
    </message>
    <message>
        <location filename="changer.ui" line="57"/>
        <source>%Platform% and %Subplatform% are expanded to the windowing system and the operation system.
%Security% is expanded to U if SSL is enabled, otherwise N.
%Locale% is replaced with current locale name.
%WebKitVersion% is expanded to WebKit version.
%AppVersion% is expanded to the application&apos;s version.</source>
        <translation>%Platform% и %Subplatform% заменяются оконной подсистемой и операционной системой.
%Security% заменяется на U, если SSL включен, в противном случае на N.
%Locale% заменяется именем текущей локали.
%WebKitVersion% заменяется версией движка WebKit.
%AppVersion% заменяется версией приложения.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Poshuku::Plugins::Fua::FUA</name>
    <message>
        <location filename="fua.cpp" line="61"/>
        <source>Domain</source>
        <translation>Домен</translation>
    </message>
    <message>
        <location filename="fua.cpp" line="62"/>
        <source>Agent</source>
        <translation>Агент</translation>
    </message>
    <message>
        <location filename="fua.cpp" line="63"/>
        <source>Identification string</source>
        <translation>Строка идентификации</translation>
    </message>
    <message>
        <location filename="fua.cpp" line="102"/>
        <source>Allows to set fake user agents for different sites.</source>
        <translation>Позволяет устанавливать поддельные user-agent для различных сайтов.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="settings.ui" line="27"/>
        <source>Add...</source>
        <translation>Добавить...</translation>
    </message>
    <message>
        <location filename="settings.ui" line="34"/>
        <source>Modify...</source>
        <translation>Изменить...</translation>
    </message>
    <message>
        <location filename="settings.ui" line="41"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="settings.ui" line="65"/>
        <source>Changes would be applied immediately</source>
        <translation>Изменения будут применены сразу</translation>
    </message>
</context>
<context>
    <name>poshukufuasettings</name>
    <message>
        <location filename="dummyfile.cpp" line="2"/>
        <source>FUA settings</source>
        <translation>Настройки FUA</translation>
    </message>
</context>
</TS>
